@@ -7,9 +7,7 @@ import sys
 
 from ..enums._ui_enum import ElementExpEnum, ElementOperationEnum, DeviceEnum, BrowserTypeEnum, DriveTypeEnum
 
-python_version = sys.version_info
-if f"{python_version.major}.{python_version.minor}" != "3.10":
-    raise Exception("必须使用>Python3.10.4")
+
 __all__ = [
     'ElementOperationEnum',
     'DeviceEnum',
