@@ -6,9 +6,7 @@ import sys
 
 from ..models._ui_model import ElementModel, ElementResultModel
 
-python_version = sys.version_info
-if f"{python_version.major}.{python_version.minor}" != "3.10":
-    raise Exception("必须使用>Python3.10.4")
+
 __all__ = [
     'ElementModel',
     'ElementResultModel',
