@@ -45,8 +45,7 @@ class ElementResultModel(BaseModel):
     type: int
     ope_key: str | None = None
     ope_value: dict = {}
-    expect: str | None = None
-    actual: str | None = None
+    ass_msg: str | None = None
     sql: str | None = None
     key_list: str | None = None
     key: str | None = None
