@@ -9,9 +9,7 @@ from ..uidrive._base_data import BaseData
 from ..uidrive._driver_object import DriverObject
 from ..uidrive._sync_element import SyncElement
 
-python_version = sys.version_info
-if f"{python_version.major}.{python_version.minor}" != "3.10":
-    raise Exception("必须使用>Python3.10.4")
+
 __all__ = [
     'AsyncElement',
     'BaseData',
