@@ -35,7 +35,8 @@ class AsyncWebNewBrowser:
                  web_h5=None,
                  is_header_intercept=False,
                  web_is_default=False,
-                 videos_path=None
+                 videos_path=None,
+                 log=None,
                  ):
         self.lock = asyncio.Lock()
         self.web_type = web_type
@@ -47,6 +48,7 @@ class AsyncWebNewBrowser:
         self.web_is_default = web_is_default
         self.is_header_intercept = is_header_intercept
         self.videos_path = videos_path
+        self.log = log
         self.browser_path = ['chrome.exe', 'msedge.exe', 'firefox.exe', '苹果', '360se.exe']
         self.browser: Optional[None | Browser] = None
         self.playwright: Optional[None | Playwright] = None
@@ -61,9 +63,9 @@ class AsyncWebNewBrowser:
             context = await self.new_context()
             page = await self.new_page(context)
             return context, page
-        except Exception as error:
+        except Exception:
+            self.log.error(f'初始化page失败，错误信息：{traceback.format_exc()}')
             self.browser = None
-            print(traceback.format_exc())
             if count >= 3:
                 raise MangoAutomationError(*ERROR_MSG_0057)
             else:
@@ -82,7 +84,8 @@ class AsyncWebNewBrowser:
         if self.web_is_default:
             try:
                 return await browser.launch()
-            except Error:
+            except Error as error:
+                self.log.error(f'初始化浏览器失败-1，类型：{error}，详情：{traceback.format_exc()}')
                 raise MangoAutomationError(*ERROR_MSG_0062)
         else:
             try:
@@ -97,7 +100,8 @@ class AsyncWebNewBrowser:
                         headless=self.web_headers,
                         executable_path=self.web_path if self.web_path else self.__search_path()
                     )
-            except Error:
+            except Error as error:
+                self.log.error(f'初始化浏览器失败-2，类型：{error}，详情：{traceback.format_exc()}')
                 raise MangoAutomationError(*ERROR_MSG_0009, value=(self.web_path,))
 
     async def new_context(self) -> BrowserContext:
@@ -115,10 +119,12 @@ class AsyncWebNewBrowser:
     async def new_page(self, context: BrowserContext) -> Page:
         try:
             page = await context.new_page()
+            page.set_default_timeout(3000)
             if self.is_header_intercept:
                 await page.route("**/*", self.wen_intercept_request)  # 应用拦截函数到页面的所有请求
             return page
-        except Error:
+        except Error as error:
+            self.log.error(f'初始化page失败，类型：{error}，详情：{traceback.format_exc()}')
             raise MangoAutomationError(*ERROR_MSG_0009, value=(self.web_path,))
 
     async def close(self):
