@@ -24,7 +24,6 @@ from ....exceptions import MangoAutomationError
 from ....exceptions._error_msg import ERROR_MSG_0057, ERROR_MSG_0008, ERROR_MSG_0062, ERROR_MSG_0009, ERROR_MSG_0055
 
 
-
 class SyncWebNewBrowser:
 
     def __init__(self,
@@ -36,7 +35,8 @@ class SyncWebNewBrowser:
                  web_h5=None,
                  is_header_intercept=False,
                  web_is_default=False,
-                 videos_path=None
+                 videos_path=None,
+                 log=None,
                  ):
         self.lock = threading.Lock()
         self.web_type = web_type
@@ -48,6 +48,7 @@ class SyncWebNewBrowser:
         self.web_is_default = web_is_default
         self.videos_path = videos_path
         self.is_header_intercept = is_header_intercept
+        self.log = log
         self.browser_path = ['chrome.exe', 'msedge.exe', 'firefox.exe', '苹果', '360se.exe']
         self.browser: Optional[None | Browser] = None
         self.playwright: Optional[None | Playwright] = None
@@ -55,15 +56,16 @@ class SyncWebNewBrowser:
     def new_web_page(self, count=0) -> tuple[BrowserContext, Page]:
         if self.browser is None:
             with self.lock:
-                self.browser = self.new_browser()
-                time.sleep(1)
+                if self.browser is None:
+                    self.browser = self.new_browser()
+                    time.sleep(1)
         try:
             context = self.new_context()
             page = self.new_page(context)
             return context, page
-        except Exception as error:
+        except Exception:
+            self.log.error(f'初始化page失败，错误信息：{traceback.format_exc()}')
             self.browser = None
-            traceback.format_exc()
             if count >= 3:
                 raise MangoAutomationError(*ERROR_MSG_0057)
             else:
@@ -82,7 +84,8 @@ class SyncWebNewBrowser:
         if self.web_is_default:
             try:
                 return browser.launch()
-            except Error:
+            except Error as error:
+                self.log.error(f'初始化浏览器失败-1，类型：{error}，详情：{traceback.format_exc()}')
                 raise MangoAutomationError(*ERROR_MSG_0062)
         else:
             try:
@@ -97,7 +100,8 @@ class SyncWebNewBrowser:
                         headless=self.web_headers,
                         executable_path=self.web_path if self.web_path else self.__search_path()
                     )
-            except Error:
+            except Error as error:
+                self.log.error(f'初始化浏览器失败-2，类型：{error}，详情：{traceback.format_exc()}')
                 raise MangoAutomationError(*ERROR_MSG_0009, value=(self.web_path,))
 
     def new_context(self) -> BrowserContext:
@@ -115,10 +119,12 @@ class SyncWebNewBrowser:
     def new_page(self, context: BrowserContext) -> Page:
         try:
             page = context.new_page()
+            page.set_default_timeout(3000)
             if self.is_header_intercept:
                 page.route("**/*", self.wen_intercept_request)  # 应用拦截函数到页面的所有请求
             return page
-        except Error:
+        except Error as error:
+            self.log.error(f'初始化page失败，类型：{error}，详情：{traceback.format_exc()}')
             raise MangoAutomationError(*ERROR_MSG_0009, value=(self.web_path,))
 
     def close(self):
